;; Generated package description from brief.el  -*- no-byte-compile: t -*-
(define-package "brief" "5.88.22.2.0.20230201.162442" "Brief Editor Emulator (Brief Mode)" '((nadvice "0.3") (cl-lib "0.5")) :commit "94471036e4fd356d6c8a7dd72622123e18c95e75" :url "https://elpa.gnu.org/packages/brief.html" :authors '(("Luke Lee" . "luke.yx.lee@gmail.com")) :maintainer '("Luke Lee" . "luke.yx.lee@gmail.com") :keywords '("brief" "emulations" "crisp"))
